import { EventEmitter, ElementRef, Renderer } from '@angular/core';
import { ImageLoaderConfig } from "../providers/image-loader-config";
export declare class ImgLoader {
    private element;
    private renderer;
    private config;
    /**
     * The URL of the image to load.
     */
    imageUrl: string;
    /**
     * The URL of the image to show if an error occurs. Leave this blank to not show anything.
     */
    errorImage: string;
    /**
     * The name of the Ionic Spinner to show while loading. Leave this blank to not show anything.
     */
    spinner: string;
    /**
     * Event emitter that notifies you when the image is loaded
     * @type {EventEmitter<void>}
     */
    onLoad: EventEmitter<void>;
    /**
     * Event emiter that notifies you when an error occurs, and passes you the error response/message.
     * @type {EventEmitter<any>}
     */
    onError: EventEmitter<any>;
    /**
     * The tag name of the element this directive is attached to.
     * This is used to determine whether we're on an `img` tag or something else.
     */
    private tagName;
    /**
     * Whether the image is still loading
     */
    private isLoading;
    /**
     * Whether an error occurred while loading the image
     */
    error: boolean;
    constructor(element: ElementRef, renderer: Renderer, config: ImageLoaderConfig);
    ngOnInit(): void;
}
