import { Injectable } from '@angular/core';
import { Http } from '@angular/http';
import { HTTP } from 'ionic-native';
import { Platform } from 'ionic-angular';
import { ImageLoaderConfig } from "./image-loader-config";
export var ImageLoader = (function () {
    function ImageLoader(http, platform, config) {
        this.http = http;
        this.platform = platform;
        this.config = config;
        this.isNativeAvailable = false;
    }
    ImageLoader.prototype.ngOnInit = function () {
        var _this = this;
        this.platform.ready().then(function () {
            if (typeof cordovaHTTP !== 'undefined') {
                _this.isNativeAvailable = true;
            }
            else if (_this.config.isDebug) {
                console.info('ImageLoader: Falling back to @angular/http since cordovaHTTP isn\'t available');
            }
        });
    };
    ImageLoader.prototype.getRawImage = function (url) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            if (_this.isNativeAvailable) {
                // cordovaHTTP is available, lets get the image via background thread
                HTTP.get(url, {}, {})
                    .then(function (data) {
                    console.log(data);
                }, function (error) {
                });
            }
            else {
                // cordovaHTTP isn't available so we'll use @angular/http
                _this.http.get(url)
                    .subscribe(function (data) {
                    console.log(data);
                    resolve(data.arrayBuffer());
                }, function (error) {
                });
            }
        });
    };
    ImageLoader.prototype.checkIfImageExistsInCache = function (imageHash) {
        return new Promise(function (resolve, reject) {
        });
    };
    ImageLoader.prototype.hashURL = function (url) {
        var hash = 0;
        var char;
        if (url.length === 0)
            return hash.toString();
        for (var i = 0; i < url.length; i++) {
            char = url.charCodeAt(i);
            hash = ((hash << 5) - hash) + char;
            hash = hash & hash;
        }
        return hash.toString();
    };
    ImageLoader.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    ImageLoader.ctorParameters = [
        { type: Http, },
        { type: Platform, },
        { type: ImageLoaderConfig, },
    ];
    return ImageLoader;
}());
//# sourceMappingURL=image-loader.js.map